/*
 * Component:  utils
 *
 * Description:
 * 			Collecting data for a study from pbr and minsopi files
 *
 *
 * Last Updated     : $Author$
 * Update Date Time : $Date$
 * RCS File Name    : $RCSfile$
 * RCS Revision     : $Revision$
 * Locked by        : $Locker$
 * Symbolic name    : $Name$
 * State            : $State$
 */

#ifndef STUDYDATACOLLECTOR_H
#define STUDYDATACOLLECTOR_H

class StudyDataCollector {

private:

	/** Study Instance UID of the original study */
	const char * m_studyUID;

	/** Full path to study directory */
	OFString m_studyDir;

	/** Name of the PbR file (relative to study directory) */
	OFString m_pbrFileName;

	/** Name of the Min SOP I file (relative to study directory) */
	OFString m_minsopiFileName;

public:

	StudyDataCollector( const char * studyUID );

	~StudyDataCollector();

	/**
	 * Returns full path to study directory
	 * @return study directory
	 */
	inline const OFString & getStudyDirectory() const {
		return m_studyDir;
	}

	/**
	 * Return PbR file name (relative to study directory)
	 * @return PbR file name
	 */
	inline const OFString & getPbRFileName() const {
		return m_pbrFileName;
	}

	/**
	 * Return Min SOP I file name (relative to study directory)
	 * @return Min SOP I file name
	 */
	inline const OFString & getMinSOPIFileName() const {
		return m_minsopiFileName;
	}


	/**
	 * Finds study directory, PbR file and MIN SOP I file for the study.
	 */
	bool findStudyFiles();


	/**
	 * Collects original data from MIN SOP I UID and PbR object of source study
	 */
	DcmItem * collectOriginalData();

	/*
	 * Copies given tags from one DcmItem to another
	 */
//	bool copyTags( DcmItem * fromItem, DcmItem * toItem, OFList<DcmTagKey> keyList );

};

#endif
